==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_countries.lang.inc.php <==
<?php
/**
 * admin_countries.lang.inc.php 2020-3-31
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array
(
	'GM_BUTTON_ACTIVE' => 'alle aktivieren',
	'GM_BUTTON_DACH' => 'nur D, A, CH aktivieren',
	'GM_BUTTON_EU' => 'nur EU Länder aktivieren',
	'GM_BUTTON_INACTIVE' => 'alle deaktivieren',
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Länder',
	'HEADING_WARNING' => 'Änderungen in diesem Bereich können dazu führen, dass der Shop fehlerhaft arbeitet.  In der Regel sind die Einstellungen in diesem Bereich bereits standardmäßig korrekt und es ist keine Bearbeitung notwendig. Bitte führen Sie nur Änderungen durch, wenn Sie sich über die Folgen im Klaren sind!',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_COUNTRY_CODES' => 'ISO Codes',
	'TABLE_HEADING_COUNTRY_NAME' => 'Land',
	'TABLE_HEADING_STATUS' => 'Status',
	'TEXT_INFO_ADDRESS_FORMAT' => 'Adressformat:',
	'TEXT_INFO_COUNTRY_CODE_2' => 'ISO Code (2):',
	'TEXT_INFO_COUNTRY_CODE_3' => 'ISO Code (3):',
	'TEXT_INFO_COUNTRY_NAME' => 'Name:',
	'TEXT_INFO_DELETE_INTRO' => 'Sind Sie sicher, dass Sie das Land löschen möchten?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte füllen Sie alle Felder aus.',
	'TEXT_INFO_HEADING_DELETE_COUNTRY' => 'Land löschen',
	'TEXT_INFO_HEADING_EDIT_COUNTRY' => 'Land bearbeiten',
	'TEXT_INFO_HEADING_NEW_COUNTRY' => 'neues Land',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte geben Sie das neue Land mit allen relevanten Daten ein.',
    'TEST_INFO_COUNTRY_STILL_IN_USE' => 'Dieses Land kann nicht gelöscht werden, solange es von einem Kunden verwendet wird.',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/admin/admin_countries.lang.inc.php <==
<?php
/**
 * admin_countries.lang.inc.php 2020-3-31
 * Gambio GmbH
 * http://www.gambio.de
 * Copyright (c) 2020 Gambio GmbH
 * Released under the GNU General Public License (Version 2)
 * [http://www.gnu.org/licenses/gpl-2.0.html]
 */

$t_language_text_section_content_array = array
(
	'GM_BUTTON_ACTIVE' => 'alle aktivieren',
	'GM_BUTTON_DACH' => 'nur D, A, CH aktivieren',
	'GM_BUTTON_EU' => 'nur EU Länder aktivieren',
	'GM_BUTTON_INACTIVE' => 'alle deaktivieren',
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Länder',
	'HEADING_WARNING' => 'Änderungen in diesem Bereich können dazu führen, dass der Shop fehlerhaft arbeitet.  In der Regel sind die Einstellungen in diesem Bereich bereits standardmäßig korrekt und es ist keine Bearbeitung notwendig. Bitte führe nur Änderungen durch, wenn du dir über die Folgen im Klaren bist!',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_COUNTRY_CODES' => 'ISO Codes',
	'TABLE_HEADING_COUNTRY_NAME' => 'Land',
	'TABLE_HEADING_STATUS' => 'Status',
	'TEXT_INFO_ADDRESS_FORMAT' => 'Adressformat:',
	'TEXT_INFO_COUNTRY_CODE_2' => 'ISO Code (2):',
	'TEXT_INFO_COUNTRY_CODE_3' => 'ISO Code (3):',
	'TEXT_INFO_COUNTRY_NAME' => 'Name:',
	'TEXT_INFO_DELETE_INTRO' => 'Bist du sicher, dass du das Land löschen möchtest?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte fülle alle Felder aus.',
	'TEXT_INFO_HEADING_DELETE_COUNTRY' => 'Land löschen',
	'TEXT_INFO_HEADING_EDIT_COUNTRY' => 'Land bearbeiten',
	'TEXT_INFO_HEADING_NEW_COUNTRY' => 'neues Land',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte gib das neue Land mit allen relevanten Daten ein.',
    'TEST_INFO_COUNTRY_STILL_IN_USE' => 'Dieses Land kann nicht gelöscht werden, solange es von einem Kunden verwendet wird.',
);
